@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# Application Name - Health Check V1.1.1-5
+# Application Name - Health Check V1.1.1-6
 # Date 17 February 2010
 # Author - Greg Roberts (Noobmonkey @ Maemo Talk)
 # Contact - Me@Greg-roberts.com
@@ -54,15 +54,11 @@ except ImportError, err:
         print "couldn't load module. %s" % (err)
         sys.exit(2)
 
-
-
 # Set a global variable - used to send the GPS info from a function back onto its label in the GUI. I'm sure there is a much better way returning
 # the variable in a function, but this works.... Example: http://www.wellho.net/resources/ex.php4?item=y105/locvar.py
 # Setting it to "location" for now.
-
 # Location of the DPKG files
 dpkg_dir = '/var/lib/dpkg'
-
 # Global variables
 print "** Seting global variables **"
 var_g_GPS = "No GPS lock"
@@ -70,11 +66,9 @@ bname = "Move R"
 name_lookup = {}
 rootfs_id = ''
 
-
 class camerasClass(QtGui.QMainWindow):
 
 	def __init__(self, *args):
-		
 		apply(QtGui.QMainWindow.__init__, (self,) + args)
 		print "** Set basic color on rectangle **"
 		self.color = QtGui.QColor(0, 0, 0) 
@@ -89,8 +83,6 @@ class camerasClass(QtGui.QMainWindow):
 		self.lblCameraImage.setMidLineWidth(1)
 		self.lblCameraImage.setScaledContents(True)
 		self.lblCameraImage.setObjectName("lblCameraImage")
-
-		
 		# Setup and draw the button
 		self.pushButton_cam = QtGui.QPushButton(self)
 		self.pushButton_cam.setGeometry(QtCore.QRect(10, 380, 331, 71))
@@ -98,7 +90,6 @@ class camerasClass(QtGui.QMainWindow):
 		self.pushButton_cam.setText("Front camera")
 		# Tell the button what to do when it is clicked.
 		QtCore.QObject.connect(self.pushButton_cam, QtCore.SIGNAL('clicked()'), self.updateTab3)
-
 		# Setup and draw the button
 		self.pushButton_cam2 = QtGui.QPushButton(self)
 		self.pushButton_cam2.setGeometry(QtCore.QRect(350, 380, 331, 71))
@@ -106,12 +97,10 @@ class camerasClass(QtGui.QMainWindow):
 		self.pushButton_cam2.setText("Back camera")
 		# Tell the button what to do when it is clicked.
 		QtCore.QObject.connect(self.pushButton_cam2, QtCore.SIGNAL('clicked()'), self.updateTab3a)
-
 		self.exitb = QtGui.QPushButton('X', self)
 		self.exitb.setGeometry(QtCore.QRect(690, 380, 101, 71))
 		self.connect(self.exitb, QtCore.SIGNAL('clicked()'), self.close)
-
-
+		
 	def updateTab3(self):
 		print " ** Starting update3**"
 		self.pushButton_cam.setEnabled(False)
@@ -150,7 +139,6 @@ class camerasClass(QtGui.QMainWindow):
 		proxy = bus.get_object('org.freedesktop.Notifications', '/org/freedesktop/Notifications')
 		interface = dbus.Interface(proxy,dbus_interface='org.freedesktop.Notifications')
 		interface.Notify('HealthCheck', 0, 'general_refresh', 'Back Camera', 'Checking Lens Cover and taking photo', [], {}, 3000)
-
 		gl = os.popen('cat /sys/devices/platform/gpio-switch/cam_shutter/state').read()
 		gl = gl.strip()
 
@@ -186,10 +174,6 @@ class camerasClass(QtGui.QMainWindow):
 			self.lblCameraImage.setPixmap(image)
 			print " ** Finished Back camera function **"
 
-
-
-		
-
 class HelloWindow(QtGui.QMainWindow):
 
 	def __init__(self, *args):
@@ -203,38 +187,29 @@ class HelloWindow(QtGui.QMainWindow):
 		print "** Setting window details and loading form**"
 		self.setGeometry(0, 0, 800, 480)
 		self.setWindowTitle('Dead Pixel Test')
-
-
 		self.square = QtGui.QWidget(self)
 		self.square.setGeometry(0, 0, 800, 480)
 		self.square.setStyleSheet("QWidget { background-color: %s }" % self.color.name())
-
-		
 		self.red = QtGui.QPushButton('Red', self)
 		self.red.setCheckable(True)
 		self.red.move(10, 10)
 		self.connect(self.red, QtCore.SIGNAL('clicked()'), self.setRed)
-
 		self.green = QtGui.QPushButton('Green', self)
 		self.green.setCheckable(True)
 		self.green.move(10, 60)
 		self.connect(self.green, QtCore.SIGNAL('clicked()'), self.setGreen)
-
 		self.blue = QtGui.QPushButton('Blue', self)
 		self.blue.setCheckable(True)
 		self.blue.move(10, 110)
 		self.connect(self.blue, QtCore.SIGNAL('clicked()'), self.setBlue)
-
 		self.moveb = QtGui.QPushButton('Move R', self)
 		self.moveb.move(10, 160)
 		self.connect(self.moveb, QtCore.SIGNAL('clicked()'), self.moveB)
-
 		self.exitb = QtGui.QPushButton('Exit', self)
 		self.exitb.move(10, 210)
 		self.connect(self.exitb, QtCore.SIGNAL('clicked()'), self.exitB)
 		print "** Completed Hellowindow Class load **"
  
-
 	def moveB(self):
 		print "** moving buttons **"
 		global bname
@@ -260,11 +235,7 @@ class HelloWindow(QtGui.QMainWindow):
 	def exitB(self):
 		print "** Exiting Hellowindow Class - closing window **"
 		self.connect(self.exitb, QtCore.SIGNAL('clicked()'), self.close)
-		#MainWindow.show()
   
-		
-		
-
 	def setRed(self):
 		if self.red.isChecked():
 			self.color.setRed(255)
@@ -272,11 +243,9 @@ class HelloWindow(QtGui.QMainWindow):
 		else:
                         self.color.setRed(0)
                         self.red.setStyleSheet("QWidget { background-color: #006633 }")
-		
-
+                        
 		self.square.setStyleSheet("QWidget { background-color: %s }" % self.color.name())
 		
-
 	def setGreen(self):
 		if self.green.isChecked():
 			self.color.setGreen(255)
@@ -296,8 +265,6 @@ class HelloWindow(QtGui.QMainWindow):
                         self.blue.setStyleSheet("QWidget { background-color: #006633 }")
 
 		self.square.setStyleSheet("QWidget { background-color: %s }" % self.color.name())
-
-
 		
 class Ui_MainWindow(object):
 	def setupUi(self, MainWindow):
@@ -305,56 +272,45 @@ class Ui_MainWindow(object):
 		print "** start SetupUi**"
 		# declaring the previous var_g_GPS location as a global in here, this allows it to be read in here.
 		global var_g_GPS
-
 		# Set the window / form name
 		MainWindow.setObjectName("MainWindow")
-
 		# Set the window size to W800 * H420 - the size of an N900's screen!
 		MainWindow.resize(800, 420)
-
 		# Set the current font to Arial 12
 		font = QtGui.QFont()
 		font.setFamily("Arial")
 		font.setPointSize(12)
 		# Set the Mainwindow to use this font
 		MainWindow.setFont(font)
-
-		
-
-
-
-		
-		# Not sure - QTDesigner did this bit - assuming it's loading up the form and a widget
+                # Not sure - QTDesigner did this bit - assuming it's loading up the form and a widget
 		self.centralwidget = QtGui.QWidget(MainWindow)
 		self.centralwidget.setObjectName("centralwidget")
-
                 app.setStyleSheet("QPushButton {\
-    /* Let's make the size of the button 1,5 times of font size. */\
-    min-height: 1.5em;\
-    /* Font size just 1.*/\
-    font: 1em;\
-    /* Margins so that we get a little space on the left and right. */\
-    margin: 0 10px 0 10px;\
-    /* The font color */ \
-    color: white;\
-    /* Here's the background gradient with start point, end point, \
-       stop percentage and color, stop percentage and color. */\
-    background-color: #006633;\
-    /* We'll round the borders. */\
-    border-style: outset;\
-    /* Round radius will be 3px */\
-    border-radius: 3px;\
-    /* Border is only one pixel */\
-    border-width: 1px;\
-    /* Border color is now set */\
-    border-color: #C4C4C3;\
-}\2010-04-12-Running.gpx\
-/* This is style when button is pressed */\
-QPushButton:pressed {\
-    /* We'll just invert the gradient by changing the colors around. */\
-    background-color: #339933; }")
-                
-
+                    /* Let's make the size of the button 1,5 times of font size. */\
+                    min-height: 1.5em;\
+                   min-width: 7em;\
+                    /* Font size just 1.*/\
+                    font: 1em;\
+                    /* Margins so that we get a little space on the left and right. */\
+                    margin: 0 10px 0 10px;\
+                    /* The font color */ \
+                    color: white;\
+                    /* Here's the background gradient with start point, end point, \
+                       stop percentage and color, stop percentage and color. */\
+                    background-color: #006633;\
+                    /* We'll round the borders. */\
+                    border-style: outset;\
+                    /* Round radius will be 3px */\
+                    border-radius: 3px;\
+                    /* Border is only one pixel */\
+                    border-width: 1px;\
+                    /* Border color is now set */\
+                    border-color: #C4C4C3;\
+                        }\2010-04-12-Running.gpx\
+                        /* This is style when button is pressed */\
+                        QPushButton:pressed {\
+                    /* We'll just invert the gradient by changing the colors around. */\
+                    background-color: #339933; }")
 
 		# Draw the Menubar
 		fremantle = MainWindow.menuBar().addMenu("Update");
@@ -365,58 +321,53 @@ QPushButton:pressed {\
 		actc = fremantle.addAction("Comms")
 		QtCore.QObject.connect(actc, QtCore.SIGNAL("triggered()"), self.updateTab2)
 
-		#fremantle = MainWindow.menuBar().addMenu("Applications");
-		#MainWindow.menuBar().addSeparator()
-		#actd = fremantle.addAction("Apps")
-		#QtCore.QObject.connect(actd, QtCore.SIGNAL("triggered()"), self.listpackages)
-                
-
 		# Creating the tab that i need for my application, and set it's size
 		self.tabWidget = QtGui.QTabWidget(self.centralwidget)
 		self.tabWidget.setGeometry(QtCore.QRect(0, 0, 800, 429))
 		self.tabWidget.setStyleSheet("QTabWidget::pane { /* The tab widget frame */\
-     border-top: 0px solid #006633;\
-     position: absolute;\
-     top: -0.0em;\
- }\
-\
- QTabWidget::tab-bar {\
-     alignment: center;\
-     background-color: #FFFFFF;\
- }\
-\
- /* Style the tab using the tab sub-control. Note that\
-     it reads QTabBar _not_ QTabWidget */\
- QTabBar::tab {\
-     background: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1,\
-                                 stop: 0 #006633, stop: 0.4 #006633,\
-                                 stop: 0.5 #006633, stop: 1.0 #006633);\
-     border: 2px solid #C4C4C3;\
-     border-bottom-color: #C2C7CB; /* same as the pane color */\
-     border-top-left-radius: 28px;\
-     border-top-right-radius: 28px;\
-     border-bottom-left-radius: 28px;\
-     border-bottom-right-radius: 28px;\
-     min-width: 8px;\
-     padding: 10px;\
-     height:38px;\
-     margin-right:25px;\
-     padding-left:25px;\
- }\
-\
- QTabBar::tab:selected, QTabBar::tab:hover {\
-     background: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1,\
-                                 stop: 0 #339933, stop: 0.4 #339933,\
-                                 stop: 0.5 #339933, stop: 1.0 #339933);\
- }\
-\
- QTabBar::tab:selected {\
-     border-color: #006633;\
-     border-bottom-color: #006633; /* same as pane color */\
-\
- QTabBar::scroller { /* the width of the scroll buttons */\
-         width: 50px;\
-     }")
+                     border-top: 0px solid #006633;\
+                     position: absolute;\
+                     top: 0.1em;\
+                 }\
+                \
+                 QTabWidget::tab-bar {\
+                     alignment: center;\
+                     background-color: #FFFFFF;\
+                 }\
+                \
+                 /* Style the tab using the tab sub-control. Note that\
+                     it reads QTabBar _not_ QTabWidget */\
+                 QTabBar::tab {\
+                        top: -0.0em;\
+                     background: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1,\
+                                                 stop: 0 #006633, stop: 0.4 #006633,\
+                                                 stop: 0.5 #006633, stop: 1.0 #006633);\
+                     border: 2px solid #C4C4C3;\
+                     border-bottom-color: #C2C7CB; /* same as the pane color */\
+                     border-top-left-radius: 28px;\
+                     border-top-right-radius: 28px;\
+                     border-bottom-left-radius: 28px;\
+                     border-bottom-right-radius: 28px;\
+                     min-width: 8px;\
+                     padding: 10px;\
+                     height:36px;\
+                     margin-right:25px;\
+                     padding-left:25px;\
+                 }\
+                \
+                 QTabBar::tab:selected, QTabBar::tab:hover {\
+                     background: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1,\
+                                                 stop: 0 #339933, stop: 0.4 #339933,\
+                                                 stop: 0.5 #339933, stop: 1.0 #339933);\
+                 }\
+                \
+                 QTabBar::tab:selected {\
+                     border-color: #006633;\
+                     border-bottom-color: #006633; /* same as pane color */\
+                \
+                 QTabBar::scroller { /* the width of the scroll buttons */\
+                         width: 50px;\
+                     }")
 		# Set the font size. I've gone for big... very big - so they are finger friendly.
 		font = QtGui.QFont()
 		font.setPointSize(24)
@@ -438,23 +389,20 @@ QPushButton:pressed {\
 		self.listWidget.setResizeMode(QtGui.QListView.Adjust)
 		QtCore.QObject.connect(self.listWidget, QtCore.SIGNAL("itemClicked(QListWidgetItem *)"), self.lclicked) 
                 self.listWidget.setStyleSheet("QListView {\
-     show-decoration-selected: 1; /* make the selection span the entire width of the view */\
- }\
- QListView::item:selected:!active {\
-     background-color: #339933; }\
-     QListView::item:selected:active {\
-     background-color: #339933;}\
- QListView {\
-     background-color: #339933;\
- }")
+                     show-decoration-selected: 1; /* make the selection span the entire width of the view */\
+                 }\
+                 QListView::item:selected:!active {\
+                     background-color: #339933; }\
+                     QListView::item:selected:active {\
+                     background-color: #339933;}\
+                 QListView {\
+                     background-color: #339933;\
+                 }")
 
-               
-		
-		#QListView::item:selected:active {background: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1,stop: 0 #000000, stop: 1 #FFFFFF); }\		
+                #QListView::item:selected:active {background: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1,stop: 0 #000000, stop: 1 #FFFFFF); }\		
 		# Draw the Tab Contents
 		self.tabWidget.addTab(self.tab, "")
 
-
 		# Start on tab 2!
 		self.tab_2 = QtGui.QWidget()
 		self.tab_2.setObjectName("tab_2")
@@ -466,24 +414,20 @@ QPushButton:pressed {\
 		self.listWidget2.setAlternatingRowColors(True)
 		self.listWidget2.setResizeMode(QtGui.QListView.Adjust)
 		self.listWidget2.setStyleSheet("QListView {\
-     show-decoration-selected: 1; /* make the selection span the entire width of the view */\
- }\
- QListView::item:selected:!active {\
-     background-color: #339933; }\
-     QListView::item:selected:active {\
-     background-color: #339933;}\
- QListView {\
-     background-color: #339933;\
- }")
+                     show-decoration-selected: 1; /* make the selection span the entire width of the view */\
+                 }\
+                 QListView::item:selected:!active {\
+                     background-color: #339933; }\
+                     QListView::item:selected:active {\
+                     background-color: #339933;}\
+                 QListView {\
+                     background-color: #339933;\
+                 }")
 
 		# Show the tab and draw contents
 		self.tabWidget.addTab(self.tab_2, "")
 		
-
-		# Show the tab and draw contents
-		#self.tabWidget.addTab(self.tab_3, "")
-
-		# Start on tab 4!
+		# Start on tab 3!
 		self.tab_3 = QtGui.QWidget()
 		self.tab_3.setObjectName("tab_3")
 
@@ -491,47 +435,38 @@ QPushButton:pressed {\
 		self.pushButton_snd1.setGeometry(QtCore.QRect(10, 10, 391, 51))
 		self.pushButton_snd1.setObjectName("pushButton_snd1")
 		self.pushButton_snd1.setText("Test Sound")
-		# Tell the button what to do when it is clicked. In this case i want it to run the updateTab1 function below
 		QtCore.QObject.connect(self.pushButton_snd1, QtCore.SIGNAL('clicked()'), self.updatesound)
 
 		self.pushButton_led = QtGui.QPushButton(self.tab_3)
 		self.pushButton_led.setGeometry(QtCore.QRect(10, 70, 391, 51))
 		self.pushButton_led.setObjectName("pushButton_led")
 		self.pushButton_led.setText("Test LEDs")
-		# Tell the button what to do when it is clicked. In this case i want it to run the updateTab1 function below
 		QtCore.QObject.connect(self.pushButton_led, QtCore.SIGNAL('clicked()'), self.updateLED)
 
 		self.pushButton_von = QtGui.QPushButton(self.tab_3)
 		self.pushButton_von.setGeometry(QtCore.QRect(10, 130, 391, 51))
 		self.pushButton_von.setObjectName("pushButton_von")
 		self.pushButton_von.setText("Test Vibrate")
-		# Tell the button what to do when it is clicked. In this case i want it to run the updateTab1 function below
 		QtCore.QObject.connect(self.pushButton_von, QtCore.SIGNAL('clicked()'), self.vibrateon)
 
 		self.xyscreen = QtGui.QPushButton(self.tab_3)
 		self.xyscreen.setGeometry(QtCore.QRect(10, 190, 391, 51))
 		self.xyscreen.setObjectName("xyscreen")
 		self.xyscreen.setText("Accuracy Test")
-		# Tell the button what to do when it is clicked. In this case i want it to run the updateTab1 function below
 		QtCore.QObject.connect(self.xyscreen, QtCore.SIGNAL('clicked()'), self.show_new_window2)
 
-		# Setup and draw the button
 		self.pushButton_cama = QtGui.QPushButton(self.tab_3)
 		self.pushButton_cama.setGeometry(QtCore.QRect(10, 250, 391, 51))
 		self.pushButton_cama.setObjectName("pushButton_cama")
 		self.pushButton_cama.setText("Camera Tests")
-		# Tell the button what to do when it is clicked. In this case i want it to run the updateTab1 function below
 		QtCore.QObject.connect(self.pushButton_cama, QtCore.SIGNAL('clicked()'), self.updateimage)
 		
-		# Setup and draw the button
 		self.pushButton_reboot = QtGui.QPushButton(self.tab_3)
 		self.pushButton_reboot.setGeometry(QtCore.QRect(10, 310, 391, 51))
 		self.pushButton_reboot.setObjectName("pushButton_reboot")
 		self.pushButton_reboot.setText("System Reboot")
-		# Tell the button what to do when it is clicked. In this case i want it to run the updateTab1 function below
 		QtCore.QObject.connect(self.pushButton_reboot, QtCore.SIGNAL('clicked()'), self.reboot_sys)
 
-
 		self.sound_lst = QtGui.QComboBox(self.tab_3)
 		self.sound_lst.setGeometry(QtCore.QRect(400, 10, 391, 51))
 		self.sound_lst.setObjectName("sound_lst")
@@ -539,7 +474,6 @@ QPushButton:pressed {\
 			#print f[-3:]
 			if f[-3:] == "wav":
 				self.sound_lst.addItem(f)
-		#self.sound_lst.addItem("PatternIncomingCall")
 
 		self.combo_led = QtGui.QComboBox(self.tab_3)
 		self.combo_led.setGeometry(QtCore.QRect(400, 70, 391, 51))
@@ -555,24 +489,16 @@ QPushButton:pressed {\
 		self.vibra_led.setObjectName("vibra_led")
 		self.vibra_led.addItem("PatternIncomingCall")
 		self.vibra_led.addItem("PatternIncomingMessage")
-		#self.vibra_led.addItem("PatternPowerKeyPress")
-		#self.vibra_led.addItem("PatternTouchScreen")
 		self.vibra_led.addItem("PatternChatAndEmail")
 
 		self.color_test = QtGui.QPushButton(self.tab_3)
 		self.color_test.setGeometry(QtCore.QRect(400, 190, 391, 51))
 		self.color_test.setObjectName("color_test")
 		self.color_test.setText("Dead Pixel Test")
-		# Tell the button what to do when it is clicked. In this case i want it to run the updateTab1 function below
 		QtCore.QObject.connect(self.color_test, QtCore.SIGNAL('clicked()'), self.show_new_window)
-
-
-		# Tell the button what to do when it is clicked. In this case i want it to run the updateTab1 function below
-		#QtCore.QObject.connect(self.pushButton_von, QtCore.SIGNAL('clicked()'), self.vibrateon)
-
 		self.tabWidget.addTab(self.tab_3, "")
 
-		# Start on tab 5!
+		# Start on tab 4!
 		self.tab_4 = QtGui.QWidget()
 		self.tab_4.setObjectName("tab_4")
 
@@ -581,7 +507,8 @@ QPushButton:pressed {\
 		# box of some sort
 		self.textBrowser = QtGui.QTextBrowser(self.tab_4)
 		self.textBrowser.setGeometry(QtCore.QRect(0, 10, 781, 301))
-		self.textBrowser.setText (" Health Check V1.1.1-5 \n Greg Roberts (Maemo.org - Noobmonkey) \n me@greg-roberts.com \n \n For Bugs and Feature requests: \n http://talk.maemo.org/showthread.php?p=541457 \n\n Thanks to: Mikec, Rob1n, Lcuk, W00t_ & MohammadAG.\n Many more people have helped by testing and offering support, so Thank You. \n \n April 2010.")
+		fsock = os.popen('cat readme.txt').read()
+		self.textBrowser.setText (fsock)
 		# Make the font small!!!
 		font = QtGui.QFont()
 		font.setPointSize(20)
@@ -590,7 +517,6 @@ QPushButton:pressed {\
 
 		# Draw the main Window
 		MainWindow.setCentralWidget(self.centralwidget)
-		
 		# Run the translate UI - Added by QT Designer - i have removed alot of setText's and placed them above.
 		print "** Run retranslateUi **"
 		self.retranslateUi(MainWindow)
@@ -745,10 +671,6 @@ QPushButton:pressed {\
                         self.listWidget.currentItem().setText("System Load \t\t\t" + ge.strip())
                 else:
                         print "else", sela[0].strip()
-                
-
-        
-
 
 	def show_new_window(self):           
 		win.show()
@@ -763,7 +685,6 @@ QPushButton:pressed {\
 		imagewin.showFullScreen()
 
 	def listpackages(self):
-
 		self.listApps.clear()
 		self.checkpkgs()
 		self.listApps.sortItems()
@@ -793,17 +714,13 @@ QPushButton:pressed {\
                 print "**",aa,"**"
                 self.listWidget.addItem("CPU Frequencies \t\t" + aa)
                                 	
-		
-		
-# Funtion - update GPS - Using lib-location
+        # Funtion - update GPS - Using lib-location
 	def updateGPS(self, MainWindow):
 		print "** Updating GPS Info**"
 		global var_g_GPS
 		global var_g_ALT
-		
 		# Start of the GPS Location information
 		# Please visit here for more information and code on PyMaemo GPS API - http://wiki.maemo.org/PyMaemo/Using_Location_API
-
 		loop = gobject.MainLoop()
 		control = location.GPSDControl.get_default()
 		device = location.GPSDevice()
@@ -813,17 +730,13 @@ QPushButton:pressed {\
 		control.connect("gpsd-stopped", on_stop, loop)
 		gobject.idle_add(start_location, control)
 		loop.run()
-
-		# Set the GPS tabel text       
-		#self.lbl_Alt_Info.setText(var_g_ALT)
 		self.listWidget2.addItem("GPS Position \t\t" + var_g_GPS.strip())
 		al = '/sbin/ifconfig | grep inet | grep -v 127.0.0.1 | awk \'{split($2,a,":");print a[2]}\''
 
-
-
 	def reboot_sys(self):
 		print "** reboot function running**"
 		self.CloseDialog = QtGui.QMessageBox.question(None, "Time for a Reboot!","Do you really want to reboot?",QtGui.QMessageBox.Yes|QtGui.QMessageBox.No,QtGui.QMessageBox.No)
+                self.CloseDialog.setMinimumHeight(300)
 		if self.CloseDialog == QtGui.QMessageBox.Yes:
 			print "** You pressed yes, rebooting **"
 			b = None
@@ -850,10 +763,8 @@ QPushButton:pressed {\
 		print bb
 		b = os.popen(bb)
 		b.close ()
-			  
 
-  
-# Funtion - update Firmware version label
+        # Funtion - update Firmware version label
 	def updateMaemoV(self):
 		print " ** Getting firmware version **"
 		# This one reads fremantle version number (Firmware)
@@ -1007,11 +918,6 @@ QPushButton:pressed {\
 		b = str(b)[:-12]
 		print b + "*"
 		self.listWidget2.addItem("Device IMEI \t\t" + b.strip())
-		#b.close()
-
-		#b = os.popen('run-standalone.sh dbus-send --system --type=method_call --print-reply --dest=com.nokia.phone.net /com/nokia/phone/net Phone.Net.get_registration_status').read()
-		#b=str(b)
-		#self.listWidget.addItem("Phone Registration \t" + b.strip())
 
 		print " ** Getting IP INFO*"
 		ga = os.popen('/sbin/ifconfig | awk \'/Bc/ {print $2}\' | cut -c6-').read()
@@ -1043,12 +949,6 @@ QPushButton:pressed {\
 		gl = gl.strip()[7:]
 		self.listWidget2.addItem("Bluetooth Name \t" + gl.strip())
 
-                #print " ****************************************************"
-		#print " ** Getting external IP**"
-		#ge = os.popen('wget -q -O - api.myiptest.com | awk -F"\"" \'{print $4}\'').read()
-		#QtGui.QApplication.processEvents()
-                #time.sleep(2.5)
-		#self.listWidget2.addItem("External IP \t\t\t" + ge.strip())
 
         def updateBluetooth(self):
                 print " ** Starting Bluetooth Service**"
@@ -1063,14 +963,10 @@ QPushButton:pressed {\
                 for words in s:
                         print "**** word ****"
                         print words
-		
-                
-		
+
                 self.listWidget2.addItem("Bluetooth MAC \t\t" + s[2].strip())
 
-	 
-
-# Funtion - update battery information
+        # Funtion - update battery information
 	def updateBatt(self):
 
 		print " ** Getting battery charge**"
@@ -1078,12 +974,8 @@ QPushButton:pressed {\
 		gl = gl.strip()
 		self.listWidget.addItem("Battery Charge \t\t" + gl.strip())
 
-# Funtion - update Accelerator information
+        # Funtion - update Accelerator information
 	def updateAccel(self):
-		#print " ** Importing dbus.glib **"
-		#import dbus.glib
-		#print " ** Glib done**"
-
 		# set f to = the accellerometer co-ordinates
 		# the co-ords need to be pulled out and split for easy reading
 		# Close down the co-ord file once used (Only displaying static info, not updating yet)
@@ -1099,28 +991,14 @@ QPushButton:pressed {\
 		jaccel = str(coords) + str(b)
 		
 		self.listWidget.addItem("Accelerometer \t\t\t" + jaccel)
-		
-		#Bluetooth
-		#print "performing inquiry..."
-		#nearby_devices = bluetooth.discover_devices(lookup_names = True)
-		#print "found %d devices" % len(nearby_devices)
-		#for name, addr in nearby_devices:
-			#print "  %s - %s" % (addr, name)
 
 	def vibrateon(self):
-		#print " ** importing dbus.glib**"
-		#import dbus.glib
-		#print " ** got dbus.glib**"
-
+                
 		print " ** testing vibrations**"
 		bus = dbus.SessionBus()
 		proxy = bus.get_object('org.freedesktop.Notifications', '/org/freedesktop/Notifications')
 		interface = dbus.Interface(proxy,dbus_interface='org.freedesktop.Notifications')
-		interface.Notify('HealthCheck', 0, 'general_refresh', 'Vibration TEST', 'Testing Vibrations', [], {}, 3000)
-		# set f to = the accellerometer co-ordinates
-		# the co-ords need to be pulled out and split for easy reading
-		# Close down the co-ord file once used (Only displaying static info, not updating yet)
-		
+		interface.Notify('HealthCheck', 0, 'general_refresh', 'Vibration TEST', 'Testing Vibrations', [], {}, 3000)		
 		bb = 'run-standalone.sh dbus-send --print-reply --system --dest=com.nokia.mce /com/nokia/mce/request com.nokia.mce.request.req_vibrator_pattern_activate string:' + "\'" + self.vibra_led.currentText() + "\'"
 		bb = str(bb)
 		b = os.popen(bb)
@@ -1140,8 +1018,6 @@ QPushButton:pressed {\
 		proxy = bus.get_object('org.freedesktop.Notifications', '/org/freedesktop/Notifications')
 		interface = dbus.Interface(proxy,dbus_interface='org.freedesktop.Notifications')
 		interface.Notify('HealthCheck', 0, 'general_refresh', 'LED TEST', 'Starting LED Test', [], {}, 3000)
-		
-
 		bb = 'run-standalone.sh dbus-send --system --type=method_call --dest=com.nokia.mce /com/nokia/mce/request com.nokia.mce.request.req_led_pattern_activate string:' + "\'" + self.combo_led.currentText() + "\'"
 		bb = str(bb)
 		b = os.popen(bb)
@@ -1154,13 +1030,13 @@ QPushButton:pressed {\
 		b = os.popen(bb)
 		b.close()
  
+		b.close()
 		print " ** Finished LED Patterns **"
 		bus = dbus.SessionBus()
 		proxy = bus.get_object('org.freedesktop.Notifications', '/org/freedesktop/Notifications')
 		interface = dbus.Interface(proxy,dbus_interface='org.freedesktop.Notifications')
 		interface.Notify('HealthCheck', 0, 'general_refresh', 'LED TEST', 'Completed LED Test', [], {}, 3000)
 
-
 	def updaterootfs(self):
 		print " ** Getting rootfs % used **"
 		gl = os.popen('df | awk \'$1 == "rootfs" {print $5}\'').read()
@@ -1226,7 +1102,6 @@ QPushButton:pressed {\
 		gl = os.popen('cat /sys/class/mmc_host/mmc0/cover_switch').read()
 		gl = gl.strip()
 		self.listWidget.addItem("MMC Cover State \t\t" + gl.strip())
-
 		self.cpufreq()
 
 	def updateAll(self):
@@ -1241,18 +1116,6 @@ QPushButton:pressed {\
 		progress.resize(800,220)
 		progress.setWindowTitle("Loading Healthcheck")
 		progress.show()
-
-                #progress.setlabel(QLabel*)
-		
-                #pbar = QtGui.QProgressBar(progress)
-                #progress.setBar(pbar)
-                #pbar.setMinimum(0)
-		#pbar.setMaximum(100)
-		#pbar.setValue(0)
-		
-                #fonta = QtGui.QFont()
-		#fonta.setPointSize(24)
-		#progress.setFont(fonta)
 		progress.setFont(QtGui.QFont('OldEnglish', 24,QtGui.QFont.Bold,QtGui.QFont.AllUppercase))
 
 		QtGui.QApplication.processEvents()
@@ -1306,12 +1169,13 @@ QPushButton:pressed {\
 		self.updatenetname()
 		QtGui.QApplication.processEvents()
 		progress.setWindowTitle("Loading Healthcheck - Networks")
-		progress.setValue(950)
+		progress.setValue(95)
                 self.updateBluetooth()
                 progress.setWindowTitle("Loading Comms- Bluetooth")
                 QtGui.QApplication.processEvents()
                 time.sleep(0.3)
                 self.listWidget2.sortItems()
+                QtGui.QApplication.processEvents()
                 progress.setValue(100)
                 time.sleep(0.1)
                 print " ** Finished tab 2 update **"
@@ -1358,7 +1222,6 @@ QPushButton:pressed {\
                 QtGui.QApplication.processEvents()
                 time.sleep(0.3)
                 progress.setValue(80)
-                #self.updateUptime()
                 progress.setWindowTitle("Loading System - Uptime")
                 QtGui.QApplication.processEvents()
                 time.sleep(0.3)
@@ -1417,20 +1280,18 @@ QPushButton:pressed {\
 
 		print 'done'
                 progress.hide()
-
-  
-		
+	
 	# This is the start of the QT Designer translation function - not using the translation function, but left it in, to show it is part of the class   
 	def retranslateUi(self, MainWindow):
-		MainWindow.setWindowTitle(QtGui.QApplication.translate("MainWindow", "Health Check V1.1.1-5", None, QtGui.QApplication.UnicodeUTF8))
+		MainWindow.setWindowTitle(QtGui.QApplication.translate("MainWindow", "Health Check V1.1.1-6", None, QtGui.QApplication.UnicodeUTF8))
 		self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab), QtGui.QApplication.translate("MainWindow", "System ", None, QtGui.QApplication.UnicodeUTF8))
 		self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_2), QtGui.QApplication.translate("MainWindow", "Comms ", None, QtGui.QApplication.UnicodeUTF8))
 		#self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_3), QtGui.QApplication.translate("MainWindow", "Apps", None, QtGui.QApplication.UnicodeUTF8))
 		self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_3), QtGui.QApplication.translate("MainWindow", "Tools ", None, QtGui.QApplication.UnicodeUTF8))
 		self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_4), QtGui.QApplication.translate("MainWindow", "About ", None, QtGui.QApplication.UnicodeUTF8))
 		
-# Cell_info - Taken from netmon code. Need to figure out the author so i can give proper thanks!
-# can be found here - http://repository.maemo.org/extras-devel/pool/fremantle/free/source/n/netmon/
+                # Cell_info - Taken from netmon code. Need to figure out the author so i can give proper thanks!
+                # can be found here - http://repository.maemo.org/extras-devel/pool/fremantle/free/source/n/netmon/
 	def Cellular(self,MainWindow):
 		print " ** Starting Cellular*"
 		#import dbus
@@ -1467,24 +1328,17 @@ QPushButton:pressed {\
 		text = " - %d dBm" % signalstrength[1]
 
 		self.listWidget2.addItem("Phone Signal \t\t" + text.strip())
-		#self.lbl_pSignal_Info.setText(text)
-
 		cell_id = regstatus[2] & 65535
 		cell_rnc = regstatus[2] >> 16
 		   
 		self.listWidget2.addItem("Cell RNC \t\t" + str(cell_rnc).strip())
-		##
 		self.listWidget2.addItem("Cell Status \t\t" + status)
-		#self.lbl_pRNC_Info.setText(status)
 		self.listWidget2.addItem("Cell ID \t\t\t" + str(cell_id).strip())
-		#self.lbl_CellID_Info.setText(str(cell_id))
-
 		self.listWidget2.addItem("Cell Services \t\t" + services)
-		#self.lbl_pServices_Info.setText(services)
 		print " ** Finishing Cellular **"
 
-# This is part of the Location api - link http://wiki.maemo.org/PyMaemo/Using_Location_API, uncommented by me
-# Moved out of the class by me
+                # This is part of the Location api - link http://wiki.maemo.org/PyMaemo/Using_Location_API, uncommented by me
+                # Moved out of the class by me
 def on_error(control, error, user_data):
 	print " ** Starting on error cellular function **"
 	if error == location.ERROR_USER_REJECTED_DIALOG:
@@ -1498,7 +1352,6 @@ def on_error(control, error, user_data):
 	elif error == location.ERROR_SYSTEM:
 		print "System error"
 		
-
 # This is part of the Location api - link http://wiki.maemo.org/PyMaemo/Using_Location_API, partially commented by me
 # Moved out of the class by me
 def on_changed(device, data):
